      program savghb
c
c  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
c  *                 P R O G R A N :  S A V G H B                    *
c  *                                                                 *
c  *          (S) TRESS    (AV) ERA  (G)  E  ALONG (H)/(B)           *
c  *                                                                 *
c  *     CALCULATES THE AVERAGE STRESS ALONG A SET OF POINTS FOR     *
c  *                                                                 *
c  *      1.  THE STRESS DISTRIBUTION ALONG THE MIDPLANE OF EACH     *
C  *            LAYER AND EACH INTERFACE FOR A FOUR LAYER LAMINATE.  *
c  *                                                                 *
C  *      2.  THE STRESS DISTRIBUTION ALONG THE FREE EDGE            *
C  *            OF ELEMENTS THRU THE THICKNESS FOR FOUR LAYERS       *
C  *            USING BOTH A TWO AND THREE ELEMENT AVERAGING         *
c  *                                                                 *
c  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
c         1         2         3         4         5         6         7   
c123456789012345678901234567890123456789012345678901234567890123456789012
      common sx(3,768),sy(3,768),sz(3,768)
      common syz(3,768),sxz(3,768),sxy(3,768)
      common y(17),saz(3,4,17),sayz(3,4,17), saxz(3,4,17)
C 
C   ASSIGN TAPE NO.S 5 AND 6,7,8,9 TO INPUT AND OUTPUT FILES RESPECTIVELY 
C 
      OPEN(1,FILE='lfemie_mechstress.out',STATUS='OLD',ERR=88)
      OPEN(2,FILE='lfemie_thermstress.out',STATUS='OLD',ERR=88)
      OPEN(3,FILE='lfemie_moiststress.out',STATUS='OLD',ERR=88)
      OPEN(6,FILE='savghb_stress_avg.out',STATUS='UNKNOWN',ERR=88)
      OPEN(7,FILE='data1.dat',STATUS='UNKNOWN',ERR=88)
      OPEN(8,FILE='data2.dat',STATUS='UNKNOWN',ERR=88)
      OPEN(9,FILE='data3.dat',STATUS='UNKNOWN',ERR=88)
      OPEN(10,FILE='data4.dat',STATUS='UNKNOWN',ERR=88)
      OPEN(11,FILE='data5.dat',STATUS='UNKNOWN',ERR=88)
      OPEN(12,FILE='data6.dat',STATUS='UNKNOWN',ERR=88)
      OPEN(13,FILE='data7.dat',STATUS='UNKNOWN',ERR=88)
      OPEN(14,FILE='data8.dat',STATUS='UNKNOWN',ERR=88)
      OPEN(15,FILE='data9.dat',STATUS='UNKNOWN',ERR=88)
c
      n=17
      ielem=768
      thick=0.02
c
      do 9 i=1,ielem
      read(1,10)sx(1,i),sy(1,i),sz(1,i),syz(1,i),sxz(1,i),sxy(1,i)
      read(2,10)sx(2,i),sy(2,i),sz(2,i),syz(2,i),sxz(2,i),sxy(2,i)
    9 read(3,10)sx(3,i),sy(3,i),sz(3,i),syz(3,i),sxz(3,i),sxy(3,i)
   10 format(5x,6(1x,e12.5))
c
c       CALCULATING POINTS ALONG THE NONDIMENSIONAL Y COORDINATE
C
      y(1)=0.7/8.0
      y(2)=2.0/8.0
      y(3)=3.2/8.0
      y(4)=4.2/8.0
      y(5)=5.0/8.0
      y(6)=5.725/8.0
      y(7)=6.25/8.0
      y(8)=6.65/8.0
      y(9)=7.025/8.0
      y(10)=7.325/8.0
      y(11)=7.55/8.0
      y(12)=7.715/8.0
      y(13)=7.82/8.0
      y(14)=7.885/8.0
      y(15)=7.925/8.0
      y(16)=7.955/8.0
      y(17)=7.985/8.0
c
c        FIRST INTERFACE AT LAMINATE MIDPLANE  Z=0  J=1 on S(I,J,K)
c
      do 11 k=1,6
      m=12*k-12
      saz(1,1,k)=           (sz(1,m+1)+sz(1,m+5))/2.0
      saz(2,1,k)=saz(1,1,k)+(sz(2,m+1)+sz(2,m+5))/2.0
      saz(3,1,k)=saz(2,1,k)+(sz(3,m+1)+sz(3,m+5))/2.0
c
      sayz(1,1,k)=            (syz(1,m+1)+syz(1,m+5))/2.0
      sayz(2,1,k)=sayz(1,1,k)+(syz(2,m+1)+syz(2,m+5))/2.0
      sayz(3,1,k)=sayz(2,1,k)+(syz(3,m+1)+syz(3,m+5))/2.0
c
      saxz(1,1,k)=            (sxz(1,m+1)+sxz(1,m+5))/2.0
      saxz(2,1,k)=saxz(1,1,k)+(sxz(2,m+1)+sxz(2,m+5))/2.0
      saxz(3,1,k)=saxz(2,1,k)+(sxz(3,m+1)+sxz(3,m+5))/2.0
   11 continue
c
      do 12 k=7,9
      m=24*k-168
      saz(1,1,k)=           (sz(1,m+73)+sz(1,m+81))/2.0
      saz(2,1,k)=saz(1,1,k)+(sz(2,m+73)+sz(2,m+81))/2.0
      saz(3,1,k)=saz(2,1,k)+(sz(3,m+73)+sz(3,m+81))/2.0
c
      sayz(1,1,k)=            (syz(1,m+73)+syz(1,m+81))/2.0
      sayz(2,1,k)=sayz(1,1,k)+(syz(2,m+73)+syz(2,m+81))/2.0
      sayz(3,1,k)=sayz(2,1,k)+(syz(3,m+73)+syz(3,m+81))/2.0
c
      saxz(1,1,k)=            (sxz(1,m+73)+sxz(1,m+81))/2.0
      saxz(2,1,k)=saxz(1,1,k)+(sxz(2,m+73)+sxz(2,m+81))/2.0
      saxz(3,1,k)=saxz(2,1,k)+(sxz(3,m+73)+sxz(3,m+81))/2.0
   12 continue
c
      do 13 k=10,12
      m=48*k-480
      saz(1,1,k)=           (sz(1,m+145)+sz(1,m+161))/2.0
      saz(2,1,k)=saz(1,1,k)+(sz(2,m+145)+sz(2,m+161))/2.0
      saz(3,1,k)=saz(2,1,k)+(sz(3,m+145)+sz(3,m+161))/2.0
c
      sayz(1,1,k)=            (syz(1,m+145)+syz(1,m+161))/2.0
      sayz(2,1,k)=sayz(1,1,k)+(syz(2,m+145)+syz(2,m+161))/2.0
      sayz(3,1,k)=sayz(2,1,k)+(syz(3,m+145)+syz(3,m+161))/2.0
c
      saxz(1,1,k)=            (sxz(1,m+145)+sxz(1,m+161))/2.0
      saxz(2,1,k)=saxz(1,1,k)+(sxz(2,m+145)+sxz(2,m+161))/2.0
      saxz(3,1,k)=saxz(2,1,k)+(sxz(3,m+145)+sxz(3,m+161))/2.0
   13 continue
      do 14 k=13,17
c
      m=96*k-1248
      saz(1,1,k)=           (sz(1,m+289)+sz(1,m+321))/2.0
      saz(2,1,k)=saz(1,1,k)+(sz(2,m+289)+sz(2,m+321))/2.0
      saz(3,1,k)=saz(2,1,k)+(sz(3,m+289)+sz(3,m+321))/2.0
c
      sayz(1,1,k)=            (syz(1,m+289)+syz(1,m+321))/2.0
      sayz(2,1,k)=sayz(1,1,k)+(syz(2,m+289)+syz(2,m+321))/2.0
      sayz(3,1,k)=sayz(2,1,k)+(syz(3,m+289)+syz(3,m+321))/2.0
c
      saxz(1,1,k)=            (sxz(1,m+289)+sxz(1,m+321))/2.0
      saxz(2,1,k)=saxz(1,1,k)+(sxz(2,m+289)+sxz(2,m+321))/2.0
      saxz(3,1,k)=saxz(2,1,k)+(sxz(3,m+289)+sxz(3,m+321))/2.0
   14 continue
C
C        STRESS AVERAGING AT 2ND 3RD AND 4TH INTERFACES
C              FOR THE SAZ SAXZ AND SAYZ STRESSES
C
C               2ND INTERFACE AT Z=  H/4    J=2 on SA__(I,J,K)
C               3RD INTERFACE AT Z=  H/2    J=3 on SA__(I,J,K)
C               4TH INTERFACE AT Z= 3H/2    J=4 on SA__(I,J,K)
C
      do 125 i=2,4
      j=i-2
      do 121 k=1,6
      m=12*k-12+j
      saz(1,i,k)=           (sz(1,m+1)+sz(1,m+2)+sz(1,m+6)+sz(1,m+9))/4.0
      saz(2,i,k)=saz(1,i,k)+(sz(2,m+1)+sz(2,m+2)+sz(2,m+6)+sz(2,m+9))/4.0
      saz(3,i,k)=saz(2,i,k)+(sz(3,m+1)+sz(3,m+2)+sz(3,m+6)+sz(3,m+9))/4.0
c
      saxz(1,i,k)=      (sxz(1,m+1)+sxz(1,m+2)+sxz(1,m+6)+sxz(1,m+9))/4.0
      saxz(2,i,k)=saxz(1,i,k)+
     *                  (sxz(2,m+1)+sxz(2,m+2)+sxz(2,m+6)+sxz(2,m+9))/4.0
      saxz(3,i,k)=saxz(2,i,k)+
     *                  (sxz(3,m+1)+sxz(3,m+2)+sxz(3,m+6)+sxz(3,m+9))/4.0
c
      sayz(1,i,k)=      (syz(1,m+1)+syz(1,m+2)+syz(1,m+6)+syz(1,m+9))/4.0
      sayz(2,i,k)=sayz(1,i,k)+
     *                  (syz(2,m+1)+syz(2,m+2)+syz(2,m+6)+syz(2,m+9))/4.0
      sayz(3,i,k)=sayz(2,i,k)+
     *                  (syz(3,m+1)+syz(3,m+2)+syz(3,m+6)+syz(3,m+9))/4.0
  121 continue      
c
      do 122 k=7,9
      m=24*k-168+j*2
      saz(1,i,k)=       (sz(1,m+74)+sz(1,m+75)+sz(1,m+83)+sz(1,m+90))/4.0
      saz(2,i,k)=saz(1,i,k)+
     *                  (sz(2,m+74)+sz(2,m+75)+sz(2,m+83)+sz(2,m+90))/4.0
      saz(3,i,k)=saz(2,i,k)+
     *                  (sz(3,m+74)+sz(3,m+75)+sz(3,m+83)+sz(3,m+90))/4.0
c
      saxz(1,i,k)=  (sxz(1,m+74)+sxz(1,m+75)+sxz(1,m+83)+sxz(1,m+90))/4.0
      saxz(2,i,k)=saxz(1,i,k)+
     *              (sxz(2,m+74)+sxz(2,m+75)+sxz(2,m+83)+sxz(2,m+90))/4.0
      saxz(3,i,k)=saxz(2,i,k)+
     *              (sxz(3,m+74)+sxz(3,m+75)+sxz(3,m+83)+sxz(3,m+90))/4.0
c
      sayz(1,i,k)=  (syz(1,m+74)+syz(1,m+75)+syz(1,m+83)+syz(1,m+90))/4.0
      sayz(2,i,k)=sayz(1,i,k)+
     *              (syz(2,m+74)+syz(2,m+75)+syz(2,m+83)+syz(2,m+90))/4.0
      sayz(3,i,k)=sayz(2,i,k)+
     *              (syz(3,m+74)+syz(3,m+75)+syz(3,m+83)+syz(3,m+90))/4.0
  122 continue
c
      do 123 k=10,12
      m=48*k-480+j*4
c
      saz(1,i,k)=   (sz(1,m+148)+sz(1,m+149)+sz(1,m+165)+sz(1,m+180))/4.0
      saz(2,i,k)=saz(1,i,k)+
     *              (sz(2,m+148)+sz(2,m+149)+sz(2,m+165)+sz(2,m+180))/4.0
      saz(3,i,k)=saz(2,i,k)+
     *              (sz(3,m+148)+sz(3,m+149)+sz(3,m+165)+sz(3,m+180))/4.0
c
      saxz(1,i,k)=
     *          (sxz(1,m+148)+sxz(1,m+149)+sxz(1,m+165)+sxz(1,m+180))/4.0
      saxz(2,i,k)=saxz(1,i,k)+
     *          (sxz(2,m+148)+sxz(2,m+149)+sxz(2,m+165)+sxz(2,m+180))/4.0
      saxz(3,i,k)=saxz(2,i,k)+
     *          (sxz(3,m+148)+sxz(3,m+149)+sxz(3,m+165)+sxz(3,m+180))/4.0
c
      sayz(1,i,k)=
     *          (syz(1,m+148)+syz(1,m+149)+syz(1,m+165)+syz(1,m+180))/4.0
      sayz(2,i,k)=sayz(1,i,k)+
     *          (syz(2,m+148)+syz(2,m+149)+syz(2,m+165)+syz(2,m+180))/4.0
      sayz(3,i,k)=sayz(2,i,k)+
     *          (syz(3,m+148)+syz(3,m+149)+syz(3,m+165)+syz(3,m+180))/4.0
  123 continue
c
      do 124 k=13,17
      m=96*k-1248+j*8
      saz(1,i,k)=
     *              (sz(1,m+296)+sz(1,m+297)+sz(1,m+329)+sz(1,m+360))/4.0
      saz(2,i,k)=saz(1,i,k)+
     *              (sz(2,m+296)+sz(2,m+297)+sz(2,m+329)+sz(2,m+360))/4.0
      saz(3,i,k)=saz(2,i,k)+
     *              (sz(3,m+296)+sz(3,m+297)+sz(3,m+329)+sz(3,m+360))/4.0
c
      saxz(1,i,k)=
     *          (sxz(1,m+296)+sxz(1,m+297)+sxz(1,m+329)+sxz(1,m+360))/4.0
      saxz(2,i,k)=saxz(1,i,k)+
     *          (sxz(2,m+296)+sxz(2,m+297)+sxz(2,m+329)+sxz(2,m+360))/4.0
      saxz(3,i,k)=saxz(2,i,k)+
     *          (sxz(3,m+296)+sxz(3,m+297)+sxz(3,m+329)+sxz(3,m+360))/4.0
c
      sayz(1,i,k)=
     *          (syz(1,m+296)+syz(1,m+297)+syz(1,m+329)+syz(1,m+360))/4.0
      sayz(2,i,k)=sayz(1,i,k)+
     *          (syz(2,m+296)+syz(2,m+297)+syz(2,m+329)+syz(2,m+360))/4.0
      sayz(3,i,K)=sayz(2,i,k)+
     *          (syz(3,m+296)+syz(3,m+297)+syz(3,m+329)+syz(3,m+360))/4.0
  124 continue
  125 continue
C
C       WRITE OUT THE     Z XZ YZ    STRESS COMPONENTS
C                        ALONG THE
C              INTERFACES BETWEEN EACH LAYER
C
c                        Mechanical Load
      write(6,210)
  210 format(15x,'---- MECHANICAL LOAD ----',//
     *,14x,'SIGMA Z  STRESS DISTRIBUTION',/,' Y POSITION   INTERFACE 1 IN
     *TERFACE 2 INTERFACE 3 INTERFACE 4')
      do 211 i=1,17
      WRITE(7,215)y(i),saz(1,1,i),saz(1,2,i),saz(1,3,i),saz(1,4,i)
  211 WRITE(6,215)y(i),saz(1,1,i),saz(1,2,i),saz(1,3,i),saz(1,4,i)
  215 FORMAT(5(1X,E11.4))
      WRITE(6,220)
  220 FORMAT(14X,'SIGMA XZ STRESS DISTRIBUTION',/,' Y POSITION   INTERFA
     *CE 1 INTERFACE 2 INTERFACE 3 INTERFACE 4')
      do 221 i=1,17
      WRITE(10,215)y(i),saxz(1,1,i),saxz(1,2,i),saxz(1,3,i),saxz(1,4,i)
  221 WRITE(6,215) y(i),saxz(1,1,i),saxz(1,2,i),saxz(1,3,i),saxz(1,4,i)
      WRITE(6,230)
  230 FORMAT(14X,'SIGMA YZ STRESS DISTRIBUTION',/,' Y POSITION   INTERFA
     *CE 1 INTERFACE 2 INTERFACE 3 INTERFACE 4')
      do 231 i=1,17
      WRITE(13,215)y(i),sayz(1,1,i),sayz(1,2,i),sayz(1,3,i),sayz(1,4,i)
  231 WRITE(6,215) y(i),sayz(1,1,i),sayz(1,2,i),sayz(1,3,i),sayz(1,4,i)
C
c                  Mechanical + Thermal Load
      write(6,310)
  310 format(//,10x,'---- MECHANICAL + THERMAL LOAD ----',//
     *,14x,'SIGMA Z  STRESS DISTRIBUTION',/,' Y POSITION   INTERFACE 1 IN
     *TERFACE 2 INTERFACE 3 INTERFACE 4')
      do 311 i=1,17
      WRITE(8,315)y(i),saz(2,1,i),saz(2,2,i),saz(2,3,i),saz(2,4,i)
  311 WRITE(6,315)y(i),saz(2,1,i),saz(2,2,i),saz(2,3,i),saz(2,4,i)
  315 FORMAT(5(1X,E11.4))
      WRITE(6,320)
  320 FORMAT(14X,'SIGMA XZ STRESS DISTRIBUTION',/,' Y POSITION   INTERFA
     *CE 1 INTERFACE 2 INTERFACE 3 INTERFACE 4')
      do 321 i=1,17
      WRITE(11,315)y(i),saxz(2,1,i),saxz(2,2,i),saxz(2,3,i),saxz(2,4,i)
  321 WRITE(6,315) y(i),saxz(2,1,i),saxz(2,2,i),saxz(2,3,i),saxz(2,4,i)
      WRITE(6,330)
  330 FORMAT(14X,'SIGMA YZ STRESS DISTRIBUTION',/,' Y POSITION   INTERFA
     *CE 1 INTERFACE 2 INTERFACE 3 INTERFACE 4')
      do 331 i=1,17
      WRITE(14,315)y(i),sayz(2,1,i),sayz(2,2,i),sayz(2,3,i),sayz(2,4,i)
  331 WRITE(6,315) y(i),sayz(2,1,i),sayz(2,2,i),sayz(2,3,i),sayz(2,4,i)
C
c                  Mechanical + Thermal + Moisture Load
      write(6,410)
  410 format(//,5x,'---- MECHANICAL + THERMAL + MOISTURE LOAD ----',//
     *,14x,'SIGMA Z  STRESS DISTRIBUTION',/,' Y POSITION   INTERFACE 1 IN
     *TERFACE 2 INTERFACE 3 INTERFACE 4')
      do 411 i=1,17
      WRITE(9,415)y(i),saz(3,1,i),saz(3,2,i),saz(3,3,i),saz(3,4,i)
  411 WRITE(6,415)y(i),saz(3,1,i),saz(3,2,i),saz(3,3,i),saz(3,4,i)
  415 FORMAT(5(1X,E11.4))
      WRITE(6,420)
  420 FORMAT(14X,'SIGMA XZ STRESS DISTRIBUTION',/,' Y POSITION   INTERFA
     *CE 1 INTERFACE 2 INTERFACE 3 INTERFACE 4')
      do 421 i=1,17
      WRITE(12,415)y(i),saxz(3,1,i),saxz(3,2,i),saxz(3,3,i),saxz(3,4,i)
  421 WRITE(6,415) y(i),saxz(3,1,i),saxz(3,2,i),saxz(3,3,i),saxz(3,4,i)
      WRITE(6,430)
  430 FORMAT(14X,'SIGMA YZ STRESS DISTRIBUTION',/,' Y POSITION   INTERFA
     *CE 1 INTERFACE 2 INTERFACE 3 INTERFACE 4')
      do 431 i=1,17
      WRITE(15,415)y(i),sayz(3,1,i),sayz(3,2,i),sayz(3,3,i),sayz(3,4,i)
  431 WRITE(6,415) y(i),sayz(3,1,i),sayz(3,2,i),sayz(3,3,i),sayz(3,4,i)
C
   88 STOP
      END
